Module oqtant.tests.integration.authorize
=========================================

Functions
---------


`authorize()`
:


`generate_challenge(verifier: str) ‑> str`
:


`generate_random(length: int) ‑> str`
:


`get_token(verifier: str, code: str)`
:


`get_user_token()`
:


`main(code)`
:


`run()`
:


`start() ‑> multiprocessing.context.Process`
:   This function to start a new process (start the server).


`stop(proc: multiprocessing.context.Process)`
:   This function to join (stop) the process (stop the server).
